import * as API from "api/virtual/properties";
export default {
    props: {
        show: {
            type: Boolean,
            default: false
        },
        title: {//弹窗标题
            type: String,
            default: ''
        },
        id: {//企业id
            type: [String, Number],
            default: ''
        },
        name: {//企业名称
            type: String,
            default: ''
        },
        packagetype: {//企业所属套餐类型
            type: String,
            default: '',
        },
        applyid: {//平台应用ID用来获取车型
            type: [String, Number],
            default: ''
        },
        propertyId: {//配置ID
            type: [String, Number],
            default: ''
        },
        parentId: {//父级ID
            type: [String, Number],
            default: ''
        },
        level: {//层级标志
            type: String,
            default: '',
        }
    },
    data() {
        return {
            my_show: false,
            loading: false,
            carTypeList: {},//车辆类型列表
            carTypeSetList: [],//车辆类型配置列表
            package: {
                show: false,
                title: '',
                id: '',//企业id
                packagetype: '',//校正过的套餐类型
                propertyId: '',//配置ID
                parentId: '',//父级ID
                level: '',//层级标志
            },
        };
    },
    mounted() {
        this.$root.$on("close", data => {
            this.visibleChange();
        });
    },
    beforeDestroy() {
        this.$root.$off("close");
    },
    components: {
        packageSet: resolve => require(['views/virtual/properties/package_set'], resolve),
    },
    watch: {
        show(bool) {
            this.my_show = bool;
            if (bool) {
                this.getCarTypeList();
                this.getPlatformSetList();
            }
        },
    },
    methods: {
        getCarTypeList() {
            let data = new Object;
            data.name = this.name;
            API.getApplyList(data)
                .then(res => {
                    if (res.code == 0) {
                        res.data.forEach(item => {
                            if (item.application.id == this.applyid) {
                                this.carTypeList = item.carType;
                            }
                        })
                    }
                })
        },
        getPlatformSetList() {
            let data = new Object;
            data.propertyId = this.propertyId;
            data.parentId = this.parentId;
            API.getPlatformSetList(data)
                .then(res => {
                    if (res.code == 0) {
                        this.carTypeSetList = res.data;
                    }
                })
        },
        addSet() {
            const index = this.carTypeSetList.length;
            const level = `${this.level}#${this.parentId}`
            const data = {
                parentId: this.parentId,
                propertyId: this.propertyId,
                type: 2,
                level: level,
                info: {
                    vehicleTypeName: '',//车辆类型名称
                    parentName: '',//车辆类型所属分类名称
                    percent: '',//占比
                }
            }
            this.$set(this.carTypeSetList, index, data);
        },
        delSet(data, index) {
            const _this = this;
            if (data.id) {
                this.$Modal.confirm({
                    title: '警告',
                    content: '删除后，会将后续配置全部删除！',
                    onOk: function () {
                        const carTypeSetList = JSON.parse(JSON.stringify(_this.carTypeSetList));
                        if (carTypeSetList.length != 1) {
                            let percentTotal = 0;
                            let isSave = true;
                            carTypeSetList.forEach((item, num) => {
                                if (item.info.vehicleTypeName && index != num) {
                                    if (item.info.percent <= 0) {
                                        _this.$Message.error('删除项除外的每个车型占比必须大于零');
                                        isSave = false;
                                    } else {
                                        percentTotal += Number(item.info.percent);
                                    }
                                }
                            })
                            if (percentTotal != 100) {
                                _this.$Message.error('删除项除外占比总和必须等于100');
                                return false;
                            }
                            if (!isSave) {
                                return false;
                            }
                        }
                        let obj = new Object;
                        obj.id = data.id;
                        obj.level = data.level;
                        API.delPlatformSet(obj)
                            .then(res => {
                                if (res.code == 0) {
                                    _this.carTypeSetList.splice(index, 1);
                                    _this.delSave();
                                }
                            })
                    }
                })
            } else {
                this.carTypeSetList.splice(index, 1);
            }
        },
        delSave() {
            const carTypeSetList = JSON.parse(JSON.stringify(this.carTypeSetList));
            let params = carTypeSetList.filter((item) => {
                if (item.info.vehicleTypeName) {
                    item.info = JSON.stringify(item.info);
                    return true;
                } else {
                    return false;
                }
            })
            let obj = new Object;
            obj.list = params;
            API.savePlatformSet(obj)
                .then(res => {
                    if (res.code == 0) {
                        this.carTypeSetList = res.data;
                    }
                })
        },
        handleSelect(data, index) {
            this.carTypeSetList.forEach((item, num) => {
                if (index != num) {
                    if (item.info.vehicleTypeName == data.value) {
                        this.$Message.error('车型不能重复');
                        this.$nextTick(() => {
                            this.$set(this.carTypeSetList[index].info, 'vehicleTypeName', '')
                        })
                    }
                }
            })
            this.carTypeSetList[index].info.parentName = data.label;
        },
        packageSet(data, index) {
            const carTypeSetList = JSON.parse(JSON.stringify(this.carTypeSetList))
            let percentTotal = 0;
            let isSave = true;
            let params = carTypeSetList.filter((item) => {
                if (item.info.vehicleTypeName) {
                    if (item.info.percent <= 0) {
                        this.$Message.error('每个平台占比必须大于零');
                        isSave = false;
                    } else {
                        percentTotal += Number(item.info.percent);
                    }
                    item.info = JSON.stringify(item.info);
                    return true;
                } else {
                    return false;
                }
            })
            if (percentTotal != 100) {
                this.$Message.error('占比总和必须等于100');
                return false;
            }
            if (!isSave) {
                return false;
            }
            let obj = new Object;
            obj.list = params;
            API.savePlatformSet(obj)
                .then(res => {
                    if (res.code == 0) {
                        this.carTypeSetList = res.data;
                        const titleList = this.title.split('-');
                        this.package.title = `${titleList[0]}-${titleList[1]}-${data.info.vehicleTypeName}-产品配置`
                        this.package.id = this.id;
                        this.package.packagetype = this.hanlePackageType(data.info.vehicleTypeName);
                        this.package.propertyId = this.propertyId;
                        this.package.parentId = res.data[index].id;
                        this.package.level = res.data[index].level;
                        this.package.show = true;
                    }
                })
        },
        hanlePackageType(data) {
            const type = this.carTypeList[data];
            let packagetype = '';
            if ((this.packagetype == 'A' || this.packagetype == 'C' || this.packagetype == 'E') && type == '商用车') {
                packagetype = 'C类套餐'
            } else if ((this.packagetype == 'A' || this.packagetype == 'C' || this.packagetype == 'E') && type == '乘用车') {
                packagetype = 'A类套餐'
            } else if ((this.packagetype == 'A' || this.packagetype == 'C' || this.packagetype == 'E') && type == '其他') {
                packagetype = 'E类套餐'
            } else if ((this.packagetype == 'B' || this.packagetype == 'D' || this.packagetype == 'F') && type == '商用车') {
                packagetype = 'D类套餐'
            } else if ((this.packagetype == 'B' || this.packagetype == 'D' || this.packagetype == 'F') && type == '乘用车') {
                packagetype = 'B类套餐'
            } else if ((this.packagetype == 'B' || this.packagetype == 'D' || this.packagetype == 'F') && type == '乘用车') {
                packagetype = 'F类套餐'
            }
            return packagetype
        },
        visibleChange(bool) {
            if (!bool) {
                this.$emit('update:show', false);
            }
            this.carTypeList = {};//车辆类型列表
            this.carTypeSetList = [];
            this.package = {
                show: false,
                title: '',
                id: '',//企业id
                packagetype: '',//校正过的套餐类型
                propertyId: '',//配置ID
                parentId: '',//父级ID
                level: '',//层级标志
            };
        },
    }
};
