import * as API from "api/virtual/properties";
import draggable from "vuedraggable";

export default {
  props: {
    show: {
      type: Boolean,
      default: false
    },
    data: {
      type: Object,
      default: {}
    }
  },
  components: {
    draggable
  },
  data() {
    return {
      my_show: false,
      loading: false,
      settings: {},
      selectedPackageTab: "",
      selectedVehicleTab: "",
      completePackagesFilter: [],
      dragOptions: {
        animation: 0,
        group: "description",
        ghostClass: "ghost"
      }
    };
  },
  computed: {
    packages: {
      get() {
        return this.settings.package ? this.settings.package : {};
      },
      set(value) {
        console.log("packages", value);
      }
    },
    products: {
      get() {
        let products = this.settings.product ? this.settings.product : [];
        let packages = this.settings.package ? this.settings.package : {};

        let values = [];

        for (const key in packages) {
          values = values.concat(packages[key]);
        }

        return products.filter(v => {
          return !values.includes(v);
        });
      },
      set(array) {
        let products = this.settings.product ? this.settings.product : [];

        let values = products.filter(v => {
          return !array.includes(v);
        });

        this.settings.product = values.concat(array);
      }
    },
    vehicles: {
      get() {
        return this.settings.vehicle ? this.settings.vehicle : {};
      },
      set(value) {
        console.log("vehicles", value);
      }
    },
    vehicleTypes: {
      get() {
        let vehicleTypes = this.settings.vehicle_type ? this.settings.vehicle_type : [];
        let vehicles = this.settings.vehicle ? this.settings.vehicle : {};

        let values = [];

        for (const key in vehicles) {
          values = values.concat(vehicles[key]);
        }

        return vehicleTypes.filter(v => {
          return !values.includes(v);
        });
      },
      set(array) {
        let vehicleTypes = this.settings.vehicle_type ? this.settings.vehicle_type : [];

        let values = vehicleTypes.filter(v => {
          return !array.includes(v);
        });

        this.settings.vehicle_type = values.concat(array);
      }
    }
  },
  watch: {
    show(bool) {
      this.my_show = bool;
      if (bool) {
        if (this.data) {
          this.settings = JSON.parse(JSON.stringify(this.data));

          if (this.settings.package_type && this.settings.package_type.length) {
            this.selectedPackageTab = this.settings.package_type[0];
          }

          if (this.settings.vehicle_group && this.settings.vehicle_group.length) {
            this.selectedVehicleTab = this.settings.vehicle_group[0];
          }
        }
      }
    },
    settings(obj) {
      if (JSON.stringify(obj) != "{}") {
        this.isShowLoading(false);
      } else {
        this.isShowLoading(true);
      }
    }
  },
  methods: {
    ok() {
      this.loading = true;
      API.settingsStore({ data: this.settings })
        .then(res => {
          this.loading = false;
          if (res.code == 0) {
            this.$Message.success("修改成功");
            this.clear();
            this.$emit("store-success", res.data);
          }
        })
        .catch(err => {
          this.loading = false;
        });
    },
    visibleChange(bool) {
      if (!bool) {
        this.$emit("update:show", false);
      }
    },
    clear() {
      this.my_show = false;
    },
    handelRemove(key, value) {
      console.log(key, value);
      this.$Modal.confirm({
        title: "提示",
        content: "已设置的属性值不会因删除改变，确认是否还要删除",
        onOk: () => {
          let node;
          if (key === "package") {
            node = this.settings[key][this.selectedPackageTab];
          } else if (key === "vehicle") {
            node = this.settings[key][this.selectedVehicleTab];
          } else {
            node = this.settings[key];
          }

          let index = node.indexOf(value);
          node.splice(index, 1);

          if (key === "package") {
            this.settings[key][this.selectedPackageTab] = node;
            this.settings.product.splice(
              this.settings.product.indexOf(value),
              1
            );
          } else if (key === "vehicle") {
            this.settings[key][this.selectedVehicleTab] = node;
            this.settings.vehicle_type.splice(
              this.settings.vehicle_type.indexOf(value),
              1
            );
          } else {
            this.settings[key] = node;
          }
        }
      });
    },
    handleAdd(key) {
      let value = "";
      let node;

      if (key === "package") {
        node = this.settings[key][this.selectedPackageTab];
      } else if (key === "vehicle") {
        node = this.settings[key][this.selectedVehicleTab];
      } else {
        node = this.settings[key];
      }

      this.$Modal.confirm({
        render: h => {
          return h("Input", {
            props: {
              value: value,
              autofocus: true,
              placeholder: "请输入名称"
            },
            on: {
              input: val => {
                value = val;
              }
            }
          });
        },
        onOk: () => {
          if (value === "") {
            return this.$Message.error("名称不能为空");
          }

          node.push(value);

          if (key === "package") {
            this.settings[key][this.selectedPackageTab] = node;
            this.settings.product.push(value);
          } else if (key === "vehicle") {
            this.settings[key][this.selectedVehicleTab] = node;
            this.settings.vehicle_type.push(value);
          } else {
            this.settings[key] = node;
          }
        }
      });
    },
    handleRemovePackageType(key) {
      let value = this.settings.package_type[key];
      return new Promise(resolve => {
        this.$Modal.confirm({
          title: "提示",
          content:
            "删除套餐分类将同时删除分类及分类下的产品，但已设置的属性值不会因删除改变，请谨慎操作",
          onOk: () => {
            let products = this.settings.package[value];

            if (products) {
              for (let i = 0; i < products.length; i++) {
                const element = products[i];
                let index = this.settings.product.indexOf(element);

                if (index !== -1) {
                  this.settings.product.splice(index, 1);
                }
              }
            }

            this.settings.package_type.splice(key, 1);
            delete this.settings.package[value];

            resolve(true);
          },
          onCannel: () => {
            resolve(false);
          }
        });
      });
    },
    handleAddPackageType() {
      let value = "";

      this.$Modal.confirm({
        render: h => {
          return h("Input", {
            props: {
              value: value,
              autofocus: true,
              placeholder: "请输入套餐分类名称"
            },
            on: {
              input: val => {
                value = val;
              }
            }
          });
        },
        onOk: () => {
          if (value === "") {
            return this.$Message.error("名称不能为空");
          }

          let package_type = this.settings.package_type
            ? this.settings.package_type
            : [];

          package_type.push(value);

          this.settings.package_type = package_type;
          this.settings.package[value] = [];
        }
      });
    },
    handleRemoveVehicleGroup(key) {
      let value = this.settings.vehicle_group[key];
      return new Promise(resolve => {
        this.$Modal.confirm({
          title: "提示",
          content:
            "删除车辆类型分类将同时删除分类及分类下的车辆类型，但已设置的属性值不会因删除改变，请谨慎操作",
          onOk: () => {
            let carType = this.settings.vehicle[value];

            if (carType) {
              for (let i = 0; i < carType.length; i++) {
                const element = carType[i];
                let index = this.settings.product.indexOf(element);

                if (index !== -1) {
                  this.settings.product.splice(index, 1);
                }
              }
            }

            this.settings.vehicle_group.splice(key, 1);
            delete this.settings.vehicle[value];

            resolve(true);
          },
          onCannel: () => {
            resolve(false);
          }
        });
      });
    },
    handleAddVehicleGroup() {
      let value = "";

      this.$Modal.confirm({
        render: h => {
          return h("Input", {
            props: {
              value: value,
              autofocus: true,
              placeholder: "请输入车辆分类名称"
            },
            on: {
              input: val => {
                value = val;
              }
            }
          });
        },
        onOk: () => {
          if (value === "") {
            return this.$Message.error("名称不能为空");
          }

          let vehicle_group = this.settings.vehicle_group
            ? this.settings.vehicle_group
            : [];

          vehicle_group.push(value);

          this.settings.vehicle_group = vehicle_group;
          this.settings.vehicle[value] = [];
        }
      });
    },
    onChange(event) {
      let packages = this.packages[this.selectedPackageTab];
      this.settings.package[this.selectedPackageTab] = packages;

      let vehicles = this.vehicles[this.selectedPackageTab];
      this.settings.vehicle[this.selectedPackageTab] = vehicles;
    }
  }
};
